package com.atguigu.ssyx.acl.controller;

import com.atguigu.ssyx.acl.service.RoleService;
import com.atguigu.ssyx.common.result.Result;
import com.atguigu.ssyx.model.acl.Role;
import com.atguigu.ssyx.vo.acl.RoleQueryVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/admin/acl/role")
@Api(tags = "用户管理")
@Slf4j
public class RoleController {
    @Autowired
    private RoleService roleService;

    @ApiOperation(value = "获取角色分页列表")
    @GetMapping("{page}/{limit}")
    public Result<IPage<Role>> index(@ApiParam(name = "page", value = "当前页码", required = true)
                                     @PathVariable Long page,

                                     @ApiParam(name = "limit", value = "每页记录数", required = true)
                                     @PathVariable Long limit,

                                     @ApiParam(name = "roleQueryVo", value = "查询对象")
                                     RoleQueryVo vo) {
        IPage<Role> roleIPage = roleService.selectPage(page, limit, vo);
        return Result.success(roleIPage);
    }

    @ApiOperation(value = "获取角色")
    @GetMapping("get/{id}")
    public Result<Role> getRole(@PathVariable Long id) {
        Role role = roleService.getById(id);
        return Result.success(role);
    }

    @ApiOperation(value = "新增角色")
    @PostMapping("save")
    public Result<Role> saveRole(@RequestBody Role role) {
        roleService.save(role);
        return Result.success();
    }

    @ApiOperation(value = "更新角色")
    @PutMapping("update")
    public Result<Role> updateRole(@RequestBody Role role) {
        boolean isSuccess = roleService.updateById(role);
        return isSuccess ? Result.success() : Result.error();
    }

    @ApiOperation(value = "删除角色")
    @DeleteMapping("remove/{id}")
    public Result<Role> removeRole(@PathVariable Long id) {
        roleService.removeById(id);
        return Result.success();
    }

    @ApiOperation(value = "根据id列表删除角色")
    @DeleteMapping("batchRemove")
    public Result<List<Long>> batchRemove(@RequestBody List<Long> ids) {
        roleService.removeByIds(ids);
        return Result.success();
    }
}
